﻿using Connected.Services;
using Microsoft.Extensions.Configuration;

namespace Connected.ServiceModel.Client.Net;

internal sealed class SelectUrl : ServiceFunction<ConnectedServerUrlArgs, string>
{
	private const string Root = "https://connected.tompit.com";
	private readonly string? _rootOverride = null;

	public SelectUrl(IConfiguration configuration)
	{
		_rootOverride = configuration?.GetValue<string?>("connectedServicesRootUrl", null);
	}

	private string RootUrl => string.IsNullOrWhiteSpace(_rootOverride) ? Root : _rootOverride;

	protected override async Task<string> OnInvoke()
	{
		await Task.CompletedTask;

		return Arguments.Kind switch
		{
			ConnectedUrlKind.Root => RootUrl,
			ConnectedUrlKind.FileSystem => $"{RootUrl}/services/fileSystem",
			ConnectedUrlKind.TableStorage => $"{RootUrl}/services/tables",
			_ => throw new NotImplementedException(),
		};
	}
}
